#
# spec file for package gcad3d
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define rname gCAD3D
%define bit %(getconf LONG_BIT)
Name:           gcad3d
Version:        2.352+git20170420.b5668e9
Release:        2.2
Summary:        3D CAD-CAM application
License:        GPL-3.0
Group:          Productivity/Graphics/CAD
Url:            http://gcad3d.org
Source0:        %{name}-%{version}.tar.xz
Source100:      %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM return.patch avvissu@yandex.ru -- E: Program returns random data in a function
Patch0:         gcad3d-2.35_return.patch
# PATCH-FIX-UPSTREAM sequence-point.patch avvissu@yandex.ru -- W:Program causes undefined operation
Patch1:        	gcad3d-2.35_sequence-point.patch
BuildRequires:  ctags
BuildRequires:  doxygen
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gtk+-3.0)
ExclusiveArch:	%ix86 x86_64 %power64

%description
gCAD3D is a 3D CAD-CAM application that features an integrated 3D OpenGL
viewer, a program interpreter for geometry and NC-commands in 3D, an
integrated NC-processor, and a programming interface for user programs. It
has support for importing Step files and support for both importing and
exporting Iges, DXF, and VRML files, and for exporting SVG.

%prep
%autosetup -p1

# Rebuild G-Code
find . -type f -name \*.o -exec rm {} \;
# Building...
sed -i '/xdg-open/d' doc/gcad_doxygen.sh
# Build with optflags
sed -e '/^CPFLG/s/\((GLBCP)\)/\1 ${EXTRACFLAGS}/' \
    -e '/^C..\?FLG/s/$/ ${EXTRACFLAGS}/' \
	-i $(grep -rl 'CPFLG\|CXFLG\|CPPFLG')
# Set new gcad-version
gcad_version=$(echo %{version} | sed 's/\+\?git.*//')
gcad_date=$(echo %{version} | sed 's/.*git\([0-9]\+\)\.\?.*/\1/')
sed -e "s/\ [.0-9]\+\(.*\)\ [-0-9]\+/ $gcad_version\1 $gcad_date/"  \
    -i src/xa/gcad_version.h
# Change gtk-version
sed -i '/^VGUI/s/gtk[0-9]/gtk3/' src/options.mak
# Startproc for gCAD3D on 64bit
sed -i 's|/usr/lib|%{_libdir}|' debian/gcad3d
# Make hidden directory
sed -e '/strcat.*gCAD3D/s/gCAD3D/\.gCAD3D/' \
    -e 's/\(\~\/\)\(gCAD3D\)/\1\.\2/g' \
    -i $(grep -rl '\"gCAD3D\"\|\~\/gCAD3D')
# Find executable files
find . -name \*.txt -type f -executable -exec chmod 644 {} \;
# Fix: wrong-file-end-of-line-encoding
find . -name \*.txt -exec dos2unix -k {} \;
# Fix: implicit-fortify-decl (too many warnings)
for _file in $(grep -rl 'stdlib\.h'); do
  if ! grep 'string\.h' $_file; then
    sed -i '/stdlib\.h/a #include <string.h>' $_file
  fi
done

%build
EXTRACFLAGS="%{optflags} -fno-strict-aliasing"
export EXTRACFLAGS="${EXTRACFLAGS/-fomit-frame-pointer /}"
# see: src/option.sh
export gcad_dir_dev="$PWD"
export gcad_dir_bin="$PWD/binLinux%{bit}"
export OUTDIR="$gcad_dir_bin"
# see: src/APP/dev_setup.sh
mkdir -p $gcad_dir_bin
mkdir -p $gcad_dir_bin/plugins
mkdir -p $gcad_dir_bin/plugins/cut1
mkdir -p $gcad_dir_dev/src/tags
# see: src/APP/do
pushd src/APP
make %{?_smp_mflags} -f gcad_gui__.mak
make %{?_smp_mflags} -f gcad_gui__.mak link
make %{?_smp_mflags} -f gcad3d.mak
make %{?_smp_mflags} -f gcad3d.mak all
make %{?_smp_mflags} -f gcad3d.mak allDemos
sh ../../doc/gcad_doxygen.sh
popd

%install
install -d %{buildroot}/%{_libdir}/%{rname}/binLinux%{bit}/plugins
install -d %{buildroot}/%{_libdir}/%{rname}/binLinux%{bit}/plugins/cut1
install -d %{buildroot}/%{_datadir}/%{name}/icons
install -d %{buildroot}%{_datadir}/doc/%{name}/html
install -d %{buildroot}%{_datadir}/doc/%{name}/msg

install -Dm 0755 debian/gcad3d %{buildroot}%{_bindir}/gcad3d
install -m 0755 binLinux%{bit}/%{rname} %{buildroot}%{_libdir}/%{rname}/binLinux%{bit}/
install -m 0644 binLinux%{bit}/*.so %{buildroot}%{_libdir}/%{rname}/binLinux%{bit}/
install -m 0644 binLinux%{bit}/plugins/*.so %{buildroot}%{_libdir}/%{rname}/binLinux%{bit}/plugins/
install -m 0755 binLinux%{bit}/plugins/cut1/G-Code %{buildroot}%{_libdir}/%{rname}/binLinux%{bit}/plugins/cut1/
install -m 0644 icons/{*.png,*.xpm,*.bmp} %{buildroot}%{_datadir}/%{name}/icons/
install -m 0644 doc/html/{*.htm,*.png,*.js} %{buildroot}%{_datadir}/doc/%{name}/html/
install -m 0644 doc/msg/*.txt %{buildroot}%{_datadir}/doc/%{name}/msg/

install -Dm 0644 %{buildroot}%{_datadir}/{%{name}/icons/,pixmaps/}%{rname}.xpm
%suse_update_desktop_file -c %{rname} %{rname} "CAD-CAM-Application" %{name} %{rname} GTK Graphics 3DGraphics Engineering

%fdupes %{buildroot}%{_datadir}

%files
%defattr(-,root,root)
%if 0%{?suse_version} > 1320
%license LICENSE LICENSE_GPLv3.txt
%else
%doc LICENSE LICENSE_GPLv3.txt
%endif
%doc doc/gCAD3D_log.txt
%doc %{_datadir}/doc/%{name}
%{_bindir}/%{name}
%{_libdir}/%{rname}
%{_datadir}/%{name}
%{_datadir}/applications/%{rname}.desktop
%{_datadir}/pixmaps/%{rname}.xpm

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Apr 19 2017 avvissu@yandex.by
- Update to version 2.352+git20170420.b5668e9:
  * all curve-modifications (eg CUT) create now trimmed-curves
  * all curves now have a polygonal representation
    (see www.gCAD3D.org/doc/watertight.htm)
  * Format of message-files changed ({key} = {value}) for automatic
    translation
- Drop gcad3d-2.34_pointer-decl.patch
- Update: gcad3d-2.34_return.patch > gcad3d-2.35_return.patch
- Add gcad3d-2.25_sequence-point.patch
- Build with optflags
- Make hidden directory (~/.gCAD3D)
* Fri Apr 14 2017 avvissu@yandex.by
- Update to version 2.34+git20161016.2d825d0:
  * Plane definition extended
  * new symbol Arrowhead (N Symbol, symbolType 6)
  * selection of catalogparts fixed
  * Measure PT / Obj: normals to all types of curves added
  * Menu Display: new option "Background white"
  * automatic scaling (button "Scal.All") rewritten
  * new function: File /save Model as / JPG
  * print-module: output of surfaces
  * new print-format PDF
  * bugfix print PS
  * DXF-export: export subModels as BLOCKS
  * DXF-import: import BLOCKS as subModels
  * new plugin Demo_toolbar2
  * provide vertex-position if analytic position cannot be computed
  * bug "select ellipse in CCV" fixed
  * bug "CUT" line with single cutting-obj fixed
  * automatic support of all languages of installed messagfiles
  * new plugin Demo_toolbar1
  * new plugin Demo_appDat1
  * Undo output of applications and plugins with the UNDO-button
  * Example: DemoPlugin_Dialog.c (func UNDO_app__)
  * parameter "unlimited" added
  * Bugfix GUI_file_open__ and GUI_file_save__
  * GL_Do_Scale__ viewer bug with scroll fixed
  * GUI_file_open_1 bug "no-selection" fixed
  * Interaction bug "redo_Interaction" fixed
  * development-docu for codes - formates  improved
  * Bug "translate concatenated-curve" fixed
  * Bug "modify GIS-point" fixed (sample_gis1.gcad)
  * Bug "display html docu" (Linux only) fixed
  * minor bugfixes
- Use pkgconfig (style)
- Update patches:
  * gcad3d-2.24_pointer-decl.patch > gcad3d-2.34_pointer-decl.patch
  * gcad3d-2.34_return.patch > gcad3d-2.34_return.patch
- Drop patches:
  * gcad3d-2.24_mkdir.patch (use mkdir in spec)
  * gcad3d-2.24_destbufferoverflow.patch (build without optflags)
  * gcad3d-2.24_sequence-point.patch (build without optflags)
- Spec file cleanup
* Wed Apr 15 2015 avvissu@yandex.ru
- Initial package
